@@ -18,8 +18,8 @@ else:
     _st_rating_df = components.declare_component("st_rating_df", path=build_dir)
 
 
-def st_rating_df(data,  height, width=-1, evaluationColumn=-1, key=None):
+def st_rating_df(data,  height, width=-1, evaluationColumn=-1, colsToDownload=['Rating', 'path'], key=None):
     if(evaluationColumn==-1):
         data.insert(loc=0, column='Rating', value=np.zeros(data.shape[0]))
         evaluationColumn=0
-    return _st_rating_df(data=data, evaluationColumn=evaluationColumn,width=width, height=height, key=key)
+    return _st_rating_df(data=data, evaluationColumn=evaluationColumn, colsToDownload=colsToDownload, width=width, height=height, key=key)
